#
# spec file for package python3-paramiko
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-paramiko
Version:        2.1.1
Release:        1.1
Url:            https://github.com/paramiko/paramiko/
Summary:        SSH2 protocol library
License:        LGPL-2.1+
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/p/paramiko/paramiko-%{version}.tar.gz
BuildRequires:  python3-cryptography >= 1.1
BuildRequires:  python3-devel
BuildRequires:  python3-pyasn1 >= 0.1.7
BuildRequires:  python3-setuptools
BuildConflicts: python3-buildservice-tweak
Requires:       python3-cryptography >= 1.1
Requires:       python3-ecdsa
Requires:       python3-pyasn1 >= 0.1.7
BuildArch:      noarch

%description
This is a library for making SSH2 connections (client or server).
Emphasis is on using SSH2 as an alternative to SSL for making secure
connections between python scripts.  All major ciphers and hash methods
are supported.  SFTP client and server mode are both supported too.

%prep
%setup -q -n paramiko-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
# The --no-transport fixes a known issue with the tests
# https://github.com/paramiko/paramiko/issues/574
# Check if still failing on next release
LANG=en_US.UTF-8 python3 test.py --no-transport

%files
%defattr(-,root,root)
%doc LICENSE README.rst demos docs
%{python3_sitelib}/*

%changelog
* Tue Dec 13 2016 mimi.vx@gmail.com
- update to 2.1.1
  * A tweak to the original patch implementing gh#398 was not fully applied,
    causing calls to ~paramiko.client.SSHClient.invoke_shell to fail with
    AttributeError. This has been fixed.
  * Fix the implementation of PKey.write_private_key_file (this method is only
    publicly defined on subclasses; the fix was in the private real
    implementation) so it passes the correct params to open()
  * Add an optional timeout parameter to Transport.start_clienti
    <paramiko.transport.Transport.start_client> (and feed it the value of the
    configured connection timeout when used within SSHClient
    <paramiko.client.SSHClient>.)
  * Catch AssertionError thrown by Cryptography when attempting to load bad
    ECDSA keys, turning it into an SSHException.
  * Add a missing .closed attribute (plus ._closed because reasons) to
    ProxyCommand <paramiko.proxy.ProxyCommand>
  * Make the subprocess import in proxy.py lazy so users on platforms without
    it (such as Google App Engine) can import Paramiko successfully
  * Fix incorrect docstring/param-list for Transport.auth_gssapi_keyex
    <paramiko.transport.Transport.auth_gssapi_keyex> so it matches
    the real signature.
  * Add an environment dict argument to Client.exec_command
* Sat Aug  6 2016 arun@gmx.de
- update to version 2.0.2:
  * Fix protocol banner read errors (SSHException) which would
    occasionally pop up when using ProxyCommand gatewaying. Thanks to
    @Depado for the initial report and Paul Kapp for the fix.
  * Add a _closed private attribute to ~paramiko.channel.Channel
    objects so that they continue functioning when used as proxy
    sockets under Python 3 (e.g. as direct-tcpip gateways for other
    Paramiko connections.)
  * Apply type definitions to _winapi module from jaraco.windows
    3.6.1. This should address issues on Windows platforms that often
    result in errors like ArgumentError: [...] int too long to
    convert. Thanks to @swohlerLL for the report and Jason R. Coombs
    for the patch.
* Fri Jun 24 2016 arun@gmx.de
- update to version 2.0.1:
  * :bug:`520 (1.16+)` (Partial fix) Fix at least one instance of race
    condition driven threading hangs at end of the Python interpreter
    session. (Includes a docs update as well - always make sure to
    .close() your clients!)
  * :bug:`537 (1.16+)` Fix a bug in BufferedPipe.set_event
    <paramiko.buffered_pipe.BufferedPipe.set_event> which could cause
    deadlocks/hangs when one uses select.select against
    ~paramiko.channel.Channel objects (or otherwise calls
    Channel.fileno <paramiko.channel.Channel.fileno> after the channel
    has closed). Thanks to Przemysław Strzelczak for the report &
    reproduction case, and to Krzysztof Rusek for the fix.
* Wed May 25 2016 toddrme2178@gmail.com
- Update to 2.0.0
  * Replace PyCrypto with the Python Cryptographic Authority (PyCA)
    ‘Cryptography’ library suite.
  * Add support for 384- and 512-bit elliptic curve groups in ECDSA
    key types (aka ecdsa-sha2-nistp384 / ecdsa-sha2-nistp521).
- Update to 1.17.0
  * Add missing file-like object methods for BufferedFile and
    SFTPFile.
  * Update the module in charge of handling SSH moduli so it’s
    consistent with OpenSSH behavior re: prime number selection.
  * Clean up and enhance the README
    (and rename it to README.rst from just README).
  * Remove whitespace in our setup.py‘s install_requires as it
    triggers occasional bugs in some versions of setuptools.
  * Identify & work around a race condition in the test for
    handshake timeouts, which was causing frequent test failures
    for a subset of contributors as well as Travis-CI
    (usually, but not always, limited to Python 3.5).
  * Annotate some public attributes on Channel such as .closed.
  * Clean up setup.py to always use setuptools, not doing so was a
    historical artifact from bygone days.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Wed Nov 11 2015 toddrme2178@gmail.com
- Add --no-transport to fix a known issue with the tests
  https://github.com/paramiko/paramiko/issues/574
  Check if still failing on next release.
  The tests is currently failing on Python 3.5, but it is not
  actually Python 3.5 specific, it is just more likely to be
  encountered on Python 3.5
* Sat Nov  7 2015 arun@gmx.de
- update to version 1.16.0:
  * Streamline use of stat when downloading SFTP files via
    SFTPClient.get <paramiko.sftp_client.SFTPClient.get>; this avoids
    triggering bugs in some off-spec SFTP servers such as IBM
    Sterling. Thanks to @muraleee for the initial report and to Torkil
    Gustavsen for the patch.
  * Fully enable two-factor authentication (e.g. when a server
    requires AuthenticationMethods
    pubkey,keyboard-interactive). Thanks to @perryjrandall for the
    patch and to @nevins-b and Matt Robenolt for additional support.
  * Fix 'exec' requests in server mode to use get_string instead of
    get_text to avoid UnicodeDecodeError on non-UTF-8 input. Thanks to
    Anselm Kruis for the patch & discussion.
  * Fix line number reporting in log output regarding invalid
    known_hosts line entries. Thanks to Dylan Thacker-Smith for catch
    & patch.
  * Update the vendored Windows API addon to a more recent
    edition. Also fixes :issue:`193`, :issue:`488`,
    :issue:`498`. Thanks to Jason Coombs.
* Tue Nov  3 2015 arun@gmx.de
- update to version 1.15.4:
  * :support:`554 backported` Fix inaccuracies in the docstring for
    the ECDSA key class. Thanks to Jared Hance for the patch.
  * :support:`516 backported` Document
    ~paramiko.agent.AgentRequestHandler. Thanks to @toejough for
    report & suggestions.
  * :bug:`496` Fix a handful of small but critical bugs in Paramiko's
    GSSAPI support (note: this includes switching from PyCrypo's
    Random to os.urandom). Thanks to Anselm Kruis for catch & patch.
  * :bug:`491` (combines :issue:`62` and :issue:`439`) Implement
    timeout functionality to address hangs from dropped network
    connections and/or failed handshakes. Credit to @vazir and @dacut
    for the original patches and to Olle Lundberg for
    reimplementation.
  * :bug:`490` Skip invalid/unparseable lines in known_hosts files,
    instead of raising ~paramiko.ssh_exception.SSHException. This
    brings Paramiko's behavior more in line with OpenSSH, which
    silently ignores such input. Catch & patch courtesy of Martin
    Topholm.
  * :bug:`404` Print details when displaying
    ~paramiko.ssh_exception.BadHostKeyException objects (expected vs
    received data) instead of just "hey shit broke". Patch credit:
    Loic Dachary.
  * :bug:`469` (also :issue:`488`, :issue:`461` and like a dozen
    others) Fix a typo introduced in the 1.15 release which broke
    WinPageant support. Thanks to everyone who submitted patches, and
    to Steve Cohen who was the lucky winner of the cherry-pick
    lottery.
  * :bug:`353` (via :issue:`482`) Fix a bug introduced in the Python 3
    port which caused OverFlowError (and other symptoms) in SFTP
    functionality. Thanks to @dboreham for leading the troubleshooting
    charge, and to Scott Maxwell for the final patch.
  * :bug:`402` Check to see if an SSH agent is actually present before
    trying to forward it to the remote end. This replaces what was
    usually a useless TypeError with a human-readable
    ~paramiko.ssh_exception.AuthenticationException. Credit to Ken
    Jordan for the fix and Yvan Marques for original report.
* Wed Oct 21 2015 toddrme2178@gmail.com
- Don't build with python3-buildservice-tweak.
  It causes package tests to fail .
* Sun Oct 18 2015 arun@gmx.de
- update to version 1.15.3:
  * :support:`554 backported` Fix inaccuracies in the docstring for
    the ECDSA key class. Thanks to Jared Hance for the patch.
  * :support:`516 backported` Document
    ~paramiko.agent.AgentRequestHandler. Thanks to @toejough for
    report & suggestions.
  * :bug:`496` Fix a handful of small but critical bugs in Paramiko's
    GSSAPI support (note: this includes switching from PyCrypo's
    Random to os.urandom). Thanks to Anselm Kruis for catch & patch.
  * :bug:`491` (combines :issue:`62` and :issue:`439`) Implement
    timeout functionality to address hangs from dropped network
    connections and/or failed handshakes. Credit to @vazir and @dacut
    for the original patches and to Olle Lundberg for
    reimplementation.
  * :bug:`490` Skip invalid/unparseable lines in known_hosts files,
    instead of raising ~paramiko.ssh_exception.SSHException. This
    brings Paramiko's behavior more in line with OpenSSH, which
    silently ignores such input. Catch & patch courtesy of Martin
    Topholm.
  * :bug:`404` Print details when displaying
    ~paramiko.ssh_exception.BadHostKeyException objects (expected vs
    received data) instead of just "hey shit broke". Patch credit:
    Loic Dachary.
  * :bug:`469` (also :issue:`488`, :issue:`461` and like a dozen
    others) Fix a typo introduced in the 1.15 release which broke
    WinPageant support. Thanks to everyone who submitted patches, and
    to Steve Cohen who was the lucky winner of the cherry-pick
    lottery.
  * :bug:`353` (via :issue:`482`) Fix a bug introduced in the Python 3
    port which caused OverFlowError (and other symptoms) in SFTP
    functionality. Thanks to @dboreham for leading the troubleshooting
    charge, and to Scott Maxwell for the final patch.
  * :bug:`402` Check to see if an SSH agent is actually present before
    trying to forward it to the remote end. This replaces what was
    usually a useless TypeError with a human-readable
    ~paramiko.ssh_exception.AuthenticationException. Credit to Ken
    Jordan for the fix and Yvan Marques for original report.
* Fri Jan  9 2015 arun@gmx.de
- specfile: update copyright year
- update to 1.15.2:
  * fix bug 413: Be significantly smarter about polling & timing
    behavior when running proxy commands, to avoid unnecessary (often
    100%%!) CPU usage.
* Thu Oct  2 2014 andrea@opensuse.org
- rebuild for python3
